<?php

/**
  New regions for blocks are easy to add. Just put it in here so you have a 
  new place for extra blocks. The first part is the name of the variable to 
  place into your page.tpl.php and the second part is the human readable 
  name that will show up in your blocks administration.

  You may notice that I have not used the traditional right_sidebar and 
  left_sidebar. The reason for this is I want people to break the mindset 
  that the regions are only for sidebars. This theme does use them for such 
  since I wanted to provide a template that had the proper CSS for 
  compensating for appearing and disappearing sidebars.
  */

function hunchbaque_regions() {
  return array(
    'content_top' => t('Top content'),
    'main_supplements' => t('Primary blocks'),
    'secondary_supplements' => t('Secondary blocks'),
    'footer' => t('footer')
  );
} 

/**
  In working more and more with Drupal in a team environment and with version
  control, one stylesheet can be a bit of a bottleneck. Only one person can 
  really work on the theming. Any more than that, there are version conflicts 
  and it just ends up being a mess. Beings Drupal now has the handy function 
  to consolidate all CSS into onw cached file, we may as well take advantage 
  of it and split things up so multiple people can work on a theme at once. We 
  will assume you will be putting all stylesheets in the css folder of the 
  theme since we want to keep things tidy. So in the array below, just add the 
  name of the stylesheet you want to load with the page. The function below 
  will take care of the rest.
  */

function hunchbaque_theme_styles() {
  $output['all'] = array(
    'default.css',
    'default-classes.css',
  );
  $output['screen, projection'] = array(
    'screen-layout.css',
  );
  $output['print'] = array(
    'print.css',
  );
  return $output;
}

/*
 * Support for IE specific stylesheets. Just use the 'ie' (ie. $output['ie']) 
 * array for all versions of Internet Explorer of the version number (ie. 
 * $output['6']). Support for lt, lte, gt and gte will come at a later date. 
 */

function hunchbaque_ie_styles() {
  $output['ie'] = array(
    'ie.css',
  );
  
  return $output;
}

function hunchbaque_styles() {
  $theme_css = hunchbaque_theme_styles();
  foreach ($theme_css as $media => $value) {
    foreach ($value as $stylesheet) {
      drupal_add_css(path_to_theme().'/css/'.$stylesheet, 'theme', $media, 'true');
    }    
  }
  $css = drupal_add_css();
  print drupal_get_css($css);
  
  $ie_css = hunchbaque_ie_styles();
  $output = "\n";
  foreach ($ie_css as $version => $value) {
    if($version == 'ie'){
      $output .= '<!--[if IE]>'."\n";
    } else {
      $output .= '<!--[if IE '.$version.']>'."\n";
    }
    foreach ($value as $stylesheet) {
      $output .= '  <style type="text/css" media="screen, projection">@import "'.base_path().path_to_theme().'/'.$stylesheet.'";</style>'."\n";
    }
    $output .= '<![endif]-->'."\n";
  }
  print $output;
}

/**
  The below function is to construct a set of classes for the body tag. I 
  will admit, this is pretty much taken from the Zen theme. I have added 
  some minor changes to make it easier to compensate for additional regions 
  that you may want to put into your template. I have documented those 
  further down below.
  */

function _phptemplate_variables($hook, $vars) {
  switch ($hook) {
    case 'page':
      if (arg(0)) {
        $path_alias = drupal_get_path_alias(arg(0).'/'.arg(1));
      } 
      else {
        $path_alias = 'error';
      }
      
      // Set up a body id
      switch ($vars['is_front']) {
        case 'TRUE':
          $body_id = 'front';
          break;

        default:
          $body_id = hunchbaque_id_safe($path_alias);
          break;
      }
      $vars['body_id'] = $body_id.'-page';
      
      // Set up the body classes.
      $body_classes = array();
      
      if (!$vars['is_front']) {
        $path_plode = explode('/', $path_alias);
        $body_classes[] = $path_plode[0].'-section';
      }
      
      global $user;
      if ($user->uid > 0) {
        $vars['logged_in'] = TRUE;
      }
      else {
        $vars['logged_in'] = FALSE;
      }
      
      $body_classes[] = ($vars['is_front']) ? 'front' : 'not-front';
      $body_classes[] = ($vars['logged_in']) ? 'logged-in' : 'not-logged-in';
      if ($vars['node']->type) {
        $body_classes[] = 'ntype-'. hunchbaque_id_safe($vars['node']->type);
      }
      
      if ($vars['main_supplements']) {
        $main_sup = TRUE;
      }
            
      if ($vars['secondary_supplements']) {
        $sec_sup = TRUE;
      }

      switch (TRUE) {
      	case $main_sup && $sec_sup :
      		$body_classes[] = 'sidebars';
      		break;
      	case $main_sup :
      		$body_classes[] = 'main-sidebar';
      		break;
      	case $sec_sup :
      		$body_classes[] = 'secondary-sidebar';
      		break;
      }

      $vars['body_classes'] = implode(' ', $body_classes);
      break;

    case 'node':
      // Nodes need some classes too.
      global $user;

      $vars['is_admin'] = in_array('admin', $user->roles);
      
      $node_classes = array('node');
      if ($vars['sticky']) {
      	$node_classes[] = 'sticky';
      }
      if (!$vars['node']->status) {
      	$node_classes[] = 'node-unpublished';
      }
      $node_classes[] = 'ntype-'. hunchbaque_id_safe($vars['node']->type);
      $vars['node_classes'] = implode(' ', $node_classes);
      
      break;
      
    case 'comment':
      $node = node_load($vars['comment']->nid);
      $vars['author_comment'] = $vars['comment']->uid == $node->uid ? TRUE : FALSE;
      
      $comment_classes[] = 'comment';
      
      if ($vars['author_comment']) {
        $comment_classes[] = 'author';
      }

      if ($vars['comment']->status == 1) {
        $comment_classes[] = 'not-published';
      }
      
      if ($vars['comment']->new > 1) {
        $comment_classes[] = 'new';
      }
      
      
      $vars['comment_classes'] = implode(' ', $comment_classes);
      break;
  }
  return $vars;
}

function hunchbaque_id_safe($string) {
  if (is_numeric($string{0})) {
    // if the first character is numeric, add 'n' in front
    $string = 'n'. $string;
  }
  return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
}

/**
  The next four functions sole purpose is to make a better menu. In a 
  nutshell, it applies "first" and "last" classesto the li element.
  */

function hunchbaque_menu_tree($pid = 1) {
  if ($tree = hunchbaque_menu_tree_improved($pid)) {
    return "\n<ul class=\"menu\">\n". $tree ."</ul>\n";
  }
}

function hunchbaque_menu_tree_improved($pid = 1) {
  $menu = menu_get_menu();
  $output = '';

  if (isset($menu['visible'][$pid]) && $menu['visible'][$pid]['children']) {
    $num_children = count($menu['visible'][$pid]['children']);
    for ($i=0; $i < $num_children; ++$i) {
      $mid = $menu['visible'][$pid]['children'][$i];
      $type = isset($menu['visible'][$mid]['type']) ? $menu['visible'][$mid]['type'] : NULL;
      $children = isset($menu['visible'][$mid]['children']) ? $menu['visible'][$mid]['children'] : NULL;
      $extraclass = $i == 0 ? 'first' : ($i == $num_children-1 ? 'last' : '');
      $output .= theme('menu_item', $mid, menu_in_active_trail($mid) || ($type & MENU_EXPANDED) ? theme('menu_tree', $mid) : '', count($children) == 0, $extraclass);     
    }
  }

  return $output;
}

function hunchbaque_menu_item($mid, $children = '', $leaf = TRUE, $extraclass = '') {
  return '  <li class="'. ($leaf ? 'leaf' : ($children ? 'expanded' : 'collapsed')) . ($extraclass ? ' ' . $extraclass : '') . '">'. menu_item_link($mid, TRUE, $extraclass) . $children ."</li>\n";
}

function hunchbaque_menu_links($links) {
  if (!count($links)) {
    return '';
  }
  $num_items = count($links);
  $counter = 0;
  $level_tmp = explode('-', key($links));
  $level = $level_tmp[0];
  $output = "<ul class=\"links-$level\">\n";
  foreach ($links as $index => $link) {
    $counter++;
    $output .= '  <li class="'.$index;
    if ($counter == 1) {
      $output .= ' first';
    }
    if ($num_items == $counter) {
      $output .= ' last';
    }
    if (stristr($index, 'active')) {
      $output .= ' active';
    }
    $output .= '">'. l($link['title'], $link['href'], $link['attributes'], $link['query'], $link['fragment']) ."</li>\n";
  }
  $output .= '</ul>';

  return $output;
}

/**
  Now the menu need sto have a better active trail. If any of the pages in 
  the sub-menu of an item is active, then the primary menu keeps the 
  active class.
  */

function hunchbaque_menu_primary_links($start_level = 1, $pid = 0) {
  if (!module_exists('menu')) {
    return NULL;
  }
  if (!$pid) {
    $pid = variable_get('menu_primary_menu', 0);
  }
  if (!$pid) {
    return NULL;
  }
  if ($start_level < 1) {
    $start_level = 1;
  }
  if ($start_level > 1) {
    $trail = _menu_get_active_trail_in_submenu($pid);
    if (!$trail) {
      return NULL;
    }
    else {
      $pid = $trail[$start_level - 1];
    }
  }
  $menu = menu_get_menu();
  $links = array();
  if ($pid && is_array($menu['visible'][$pid]) && isset($menu['visible'][$pid]['children'])) {
    $count = 1;
    foreach ($menu['visible'][$pid]['children'] as $cid) {
      $index = "menu-$start_level-$count-$pid";
      if (menu_in_active_trail_in_submenu($cid, $pid)) {
        $index .= "-active active";
      }
      $links[$index] = menu_item_link($cid, FALSE);
      $count++;
    }
  }
  // Special case - provide link to admin/build/menu if primary links is empty.
  if (empty($links) && $start_level == 1 && $pid == variable_get('menu_primary_menu', 0) && user_access('administer menu')) {
    $links['1-1'] = array(
      'title' => t('Edit primary links'),
      'href' => 'admin/build/menu'
    );
  }
  return $links;
}

/**
  This is a bit of code so that one can easily edit the code that appears 
  around all of the comments in a theme. This is not to be confused with 
  what comment.tpl.php does. That is for individual comments.
  */

function hunchbaque_comment_wrapper($content, $type = null) {
  static $node_type;
  if (isset($type)) $node_type = $type;

  if (!$content || $node_type == 'forum') {
    return "<div id=\"comments\">\n  ". $content . "\n</div>\n";
  }
  else {
    return "<div id=\"comments\">\n  <h2 class=\"comments\">". t('Comments') ."</h2>\n". $content ."\n</div> <!-- /#comments -->\n\n";
  }
}

/**
  The default setup for Drupal's help notices are wierd. They appear even 
  if the only thing there is an empty paragraph. Thanks to the fact they 
  are applied with a theme function, it is fairly easy to fix with the 
  following function.
  */

function hunchbaque_help() {
  $help = menu_get_active_help();
  if ($help && $help != '<p></p>'."\n") {
    return '<div class="help">'. $help .'</div>';
  }
}
